local ui = require('ui')

display.setStatusBar( display.HiddenStatusBar )
system.setLocationAccuracy( 10 )

local isSimulator = "simulator" == system.getInfo("environment")
local deviceId = system.getInfo("deviceID")

local bg = display.newRect(0, 0, display.contentWidth, display.contentHeight)

local logo = display.newImageRect("logo.png", 172, 107)
logo.x = display.contentWidth / 2
logo.y = (display.contentHeight / 2) - 150

local titleLabel = ui.newLabel{
        bounds = { 15, 5, 290, 55 },
        text = "Message",
        font = native.systemFontBold,
        textColor = { 12, 12, 100, 255 },
        size = 24,
        align = "center"
}
titleLabel:setReferencePoint(display.TopCenterReferencePoint)
titleLabel.y = logo.y + 60


if isSimulator then
	-- Simulator (simulate the textField area)
	textField = display.newRect( 20, titleLabel.y + 60, 280, 30 )
	textField:setFillColor( 200, 200, 200 )
else
	local function fieldHandler( event )
		if ( "submitted" == event.phase ) then
			native.setKeyboardFocus( nil )
		end
	end
    textField = native.newTextField( 20, titleLabel.y + 60, 280, 30, fieldHandler )
end             

textField:setReferencePoint(display.TopCenterReferencePoint)
textField.x = display.contentWidth / 2
textField.y = titleLabel.y + 60

local removeKeyboard = function( event )
        -- Hide keyboard
        native.setKeyboardFocus( nil )
end
bg:addEventListener( "tap", removeKeyboard )


local latitudeText = ""
local longitudeText = ""
if isSimulator then
	local alert = native.showAlert( "Error", "GPS not available in Simulator" )
else
 	local locationHandler = function(event)
		latitudeText = string.format( '%.8f', event.latitude )
		longitudeText = string.format( '%.8f', event.longitude )
	end
	Runtime:addEventListener( "location", locationHandler )
end

local getThump = function(event)
	if event.isShake == true then
		local alert = native.showAlert( "Thump!", "Location: "..latitudeText..","..longitudeText.."\r\nMessage: "..textField.text, {"OK"} )
		system.vibrate()
	end
end
Runtime:addEventListener("accelerometer", getThump)

